@@ -32,7 +32,7 @@ logger = logging.getLogger('zim.fs')
 
 from zim.newfs.base import _os_expanduser, SEP
 from zim.newfs.local import AtomicWriteContext
-
+from zim.newfs.local import get_tmpdir as _newfs_get_tmpdir
 
 def adapt_from_newfs(file):
 	from zim.newfs import LocalFile, LocalFolder
@@ -45,6 +45,17 @@ def adapt_from_newfs(file):
 		return file
 
 
+def adapt_from_oldfs(file):
+	from zim.newfs import LocalFile, LocalFolder
+
+	if isinstance(file, File):
+		return LocalFile(file.path)
+	elif isinstance(file, Dir):
+		return LocalFolder(file.path)
+	else:
+		return file
+
+
 try:
 	from gi.repository import Gio
 except ImportError:
@@ -56,14 +67,16 @@ if not Gio:
 
 xdgmime = None
 mimetypes = None
-try:
-	import xdg.Mime as xdgmime
-except ImportError:
-	if os.name != 'nt':
-		logger.info("Can not import 'xdg.Mime' - falling back to 'mimetypes'")
-	else:
-		pass # Ignore this error on Windows; doesn't come with xdg.Mime
+if os.name == 'nt':
+	# On windows even if xdg is installed, the database is not (always)
+	# well initialized, so always fallback to mimetypes
 	import mimetypes
+else:
+	try:
+		import xdg.Mime as xdgmime
+	except ImportError:
+		logger.info("Can not import 'xdg.Mime' - falling back to 'mimetypes'")
+		import mimetypes
 
 
 #: Extensions to determine image mimetypes - used in L{File.isimage()}
@@ -101,6 +114,8 @@ IMAGE_EXTENSIONS = (
 	'svg', # image/svg+xml
 	'svgz', # image/svg+xml
 	'svg.gz', # image/svg+xml
+	# Custom additions
+	'webp', # image/webp
 )
 
 
@@ -114,6 +129,7 @@ def isabs(path):
 	or os.path.isabs(path)
 
 
+_tmpdir = None
 def get_tmpdir():
 	'''Get a folder in the system temp dir for usage by zim.
 	This zim specific temp folder has permission set to be readable
@@ -121,12 +137,13 @@ def get_tmpdir():
 	Used as base folder by L{TmpFile}.
 	@returns: a L{Dir} object for the zim specific tmp folder
 	'''
+	global _tmpdir
 
-	if get_tmpdir.dir is None:
-		get_tmpdir.dir = Dir(tempfile.mkdtemp(prefix='zim-'))
+	if _tmpdir is None:
+		localdir = _newfs_get_tmpdir()
+		_tmpdir = Dir(localdir.path)
 
-	return get_tmpdir.dir
-get_tmpdir.dir = None
+	return _tmpdir
 
 
 def normalize_file_uris(path):
